#' @importFrom dplyr arrange distinct filter first full_join group_by
#' @importFrom dplyr inner_join last left_join mutate n_distinct rename
#' @importFrom dplyr row_number select summarize tibble ungroup
#' @importFrom glue glue
#' @importFrom rlang %||% abort warn
#' @importFrom tidyr pivot_longer pivot_wider unnest
#' @importFrom tidyselect one_of starts_with
NULL

globalVariables("where")
